<div align="center">
    <img src="assets/youtube_analyzer-logo.png" alt="youtube_analyzer-logo" width="200"/>
  
  ![Versão](https://img.shields.io/badge/version-0.2.4-orange)
  ![Licença](https://img.shields.io/badge/license-MIT-orange)
  [![Sponsor](https://img.shields.io/badge/💲Donate-yellow)](https://apoia.se/paulocesar-dev404)
  [![Sponsor](https://img.shields.io/badge/📖Documentation-green)](https://github.com/PauloCesar-dev404/youtube_analyzer/wiki)


  <i>Obtenha detalhes completos de vídeos do YouTube com esta biblioteca incrível!</i>
  
  ---
</div>


###  Funcionalidades
- [x] Obter detalhes de um vídeo
- [x] obter legendas
- [x] Analizar playlists
- [x] Obter detalhes de uris de Vídeos
- [x] Downloads de audios e vídeos
- [x] interface linha de comando `yt-downloader`


Se tiver dúvidas ou sugestões, abra uma [issue aqui](https://github.com/PauloCesar-dev404/youtube_analyzer/issues).

---

